InviteLinkClient

Struct InviteLinkClient 

pub struct InviteLinkClient {
    pub(crate) key_store: KeyStore<KeySlotIds>,
    pub(crate) api_configurations: Arc<ApiConfigurations>,
}
Client for organization invite link cryptographic and network operations.

Fields

key_store: KeyStore<KeySlotIds>api_configurations: Arc<ApiConfigurations>

Implementations

Source

impl InviteLinkClient

Creates a new organization invite and posts it to the server, returning the full OrganizationInviteLink persisted by the server.

Security

Only the sealed invite is posted to the server; the invite secret is never sent. Use InviteLinkClient::get_invite_secret to recover the secret needed to reconstruct the invite link.

Refresh an existing invite link. This generates a new code and secret.

pub fn get_invite_secret( &self, organization_id: OrganizationId, invite: Invite, ) -> Result<InviteSecret, InviteLinkError>

Using the organization key, recovers the [InviteSecret] from the invite carried in the given OrganizationInviteLink so an admin can reconstruct the invite link.

pub async fn accept_and_optionally_confirm( &self, organization_id: OrganizationId, code: String, invite_secret: InviteSecret, default_collection_name: String, enroll_into_account_recovery: bool, ) -> Result<(), InviteLinkError>

Accepts an organization invite for the current user, optionally enrolling into account recovery (when enroll_into_account_recovery is set) and — when the invite supports confirmation — self-confirming.

async fn make_invite( &self, organization_id: OrganizationId, supports_confirmation: bool, ) -> Result<Invite, InviteLinkError>

Helper function to make a new Invite to be included in a request model.